==> cutetube_0.9.9-3.tar.gz: cutetube-0.9.9/src/opt/cutetube/customwidgets.py <==
# -*- coding: utf-8 -*-

"""
Module implementing VideoItemWidget.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *
import time

from Ui_customwidgets import Ui_VideoItemWidget,  Ui_VideoDownloadWidget

class VideoItemWidget(QWidget, Ui_VideoItemWidget):
    """
    Widget showing a video thumbnail, duration, title, 
    author and rating.
    """
    def __init__(self, video, thumbnail, parent = None):
        """
        Constructor
        """
        QWidget.__init__(self, parent)
        self.setupUi(self)
        self.checkBox.mousePressEvent = self.ignoreClick
        self.titleLabel.setText(unicode(video.title.text,  "utf-8"))
        self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(video.media.duration.seconds)))))
        self.authorLabel.setText(unicode(video.author[0].name.text, "utf-8"))
        try:
            self.thumbLabel.setPixmap(thumbnail) 
        except:
            self.thumbLabel.setPixmap(QPixmap(":/images/ui-images/thumbnail.png"))
        try:
            self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating%s.png" % unicode(round(float(video.rating.average)))))
        except:
            self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating3.0.png"))  
            
    def ignoreClick(self, event):
        """
        Propagates the mouse event to the parent.
        """
        event.ignore()

    def hideCheckBox(self):
        """
        Hides the widget's checkbox.
        """       
        self.thumbLabel.move(0, 2)
        self.durationLabel.move(53, 53)
        self.widget.setGeometry(QRect(110, 0, 690, 79))
        self.checkBox.setVisible(False)
        self.checkBox.setCheckState(Qt.Unchecked)

    def showCheckBox(self):
        """
        Displays the widget's checkbox.
        """
        self.thumbLabel.move(70, 2)
        self.durationLabel.move(123, 53)
        self.widget.setGeometry(QRect(180, 0, 620, 79))
        self.checkBox.setVisible(True)


    def toggleCheckBox(self):
        """
        Displays or removes the checkbox at the left of 
        the widget.
        """
        if not self.checkBox.isVisible():
            self.showCheckBox()
        else:
            self.hideCheckBox()

class VideoDownloadItemWidget(QWidget, Ui_VideoDownloadWidget):
    """
    Widget showing same information as VideoItemWidget 
    with an additional progress bar showing the download 
    progress.
    """
    def __init__(self, video, thumbnail, parent = None):
        """
        Constructor
        """
        QWidget.__init__(self, parent)
        self.setupUi(self)
        self.titleLabel.setText(unicode(video.title.text,  "utf-8"))
        self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(video.media.duration.seconds)))))
        self.thumbLabel.setPixmap(thumbnail)
        self.orientationChanged()
        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
        
    def orientationChanged(self):
        """
        Changes the geometry of the progressBar to keep it visible.
        """
        screenGeometry = QApplication.desktop().screenGeometry()
        if screenGeometry.height() > screenGeometry.width():
            self.widget.setGeometry(QRect(110, 2, 210, 75))
            self.progressBar.setGeometry(QRect(330, 2, 120, 75))
        else:
            self.widget.setGeometry(QRect(110, 2, 500, 75))
            self.progressBar.setGeometry(QRect(620, 2, 150, 75))

class CommentWidget(QWidget):
    """
    Widget displaying comment author and comment text.
    """
    def __init__(self, author, comment, parent = None):
        """
        Constructor
        """
        QWidget.__init__(self, parent)
        self.textEdit = QTextEdit()
        self.textEdit.setReadOnly(True)
        self.textEdit.viewport().setAutoFillBackground(False)
        self.textEdit.setFrameStyle(QFrame.NoFrame)
        self.textEdit.setStyleSheet("color: rgb(255, 255, 255); font-size: 18px")
        self.document = QTextDocument(unicode(comment, "utf-8"))
        self.textEdit.setDocument(self.document)
        self.textEdit.setFixedHeight(self.document.documentLayout().documentSize().toSize().height())
        self.authorLabel = QLabel(unicode(author, "utf-8"))
        self.authorLabel.setStyleSheet("color: rgb(120, 120, 120) ")
        self.vbox = QVBoxLayout(self)
        self.vbox.addWidget(self.authorLabel)
        self.vbox.addWidget(self.textEdit)
        self.setLayout(self.vbox)
        self.show()

class PlaylistWidget(QWidget):
    def __init__(self, title, parent = None):
        QWidget.__init__(self, parent)
        self.setMininumSize(800, 50)
        self.titleLabel = QLabel(unicode(title, "utf-8"))
        self.titleLabel.setGeometry(QRect(0, 0, 800, 50))
        self.titleLabel.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
        self.show()

==> cutetube_0.9.9-6.tar.gz: cutetube-0.9.9/src/opt/cutetube/customwidgets.py <==
# -*- coding: utf-8 -*-

"""
Module implementing VideoItemWidget.
"""

from PyQt4.QtGui import *
from PyQt4.QtCore import *
import time

from Ui_customwidgets import Ui_VideoItemWidget,  Ui_VideoDownloadWidget

class VideoItemWidget(QWidget, Ui_VideoItemWidget):
    """
    Widget showing a video thumbnail, duration, title, 
    author and rating.
    """
    def __init__(self, video, parent = None):
        """
        Constructor
        """
        QWidget.__init__(self, parent)
        self.setupUi(self)
        self.checkBox.mousePressEvent = self.ignoreClick
        self.titleLabel.setText(unicode(video.title.text,  "utf-8"))
        try:
            self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(video.media.duration.seconds)))))
        except:
            self.durationLabel.setText("--")
        self.authorLabel.setText(unicode(video.author[0].name.text, "utf-8"))
        try:
            self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating%s.png" % unicode(round(float(video.rating.average)))))
        except:
            self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating3.0.png"))  
            
    def ignoreClick(self, event):
        """
        Propagates the mouse event to the parent.
        """
        event.ignore()

    def hideCheckBox(self):
        """
        Hides the widget's checkbox.
        """       
        self.thumbLabel.move(0, 2)
        self.durationLabel.move(53, 53)
        self.widget.setGeometry(QRect(110, 0, 690, 79))
        self.checkBox.setVisible(False)
        self.checkBox.setCheckState(Qt.Unchecked)

    def showCheckBox(self):
        """
        Displays the widget's checkbox.
        """
        self.thumbLabel.move(70, 2)
        self.durationLabel.move(123, 53)
        self.widget.setGeometry(QRect(180, 0, 620, 79))
        self.checkBox.setVisible(True)


    def toggleCheckBox(self):
        """
        Displays or removes the checkbox at the left of 
        the widget.
        """
        if not self.checkBox.isVisible():
            self.showCheckBox()
        else:
            self.hideCheckBox()

class VideoDownloadItemWidget(QWidget, Ui_VideoDownloadWidget):
    """
    Widget showing same information as VideoItemWidget 
    with an additional progress bar showing the download 
    progress.
    """
    def __init__(self, video, parent = None):
        """
        Constructor
        """
        QWidget.__init__(self, parent)
        self.setupUi(self)
        self.titleLabel.setText(unicode(video.title.text,  "utf-8"))
        self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(video.media.duration.seconds)))))
        self.orientationChanged()
        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
        
    def orientationChanged(self):
        """
        Changes the geometry of the progressBar to keep it visible.
        """
        screenGeometry = QApplication.desktop().screenGeometry()
        if screenGeometry.height() > screenGeometry.width():
            self.widget.setGeometry(QRect(110, 2, 210, 75))
            self.progressBar.setGeometry(QRect(330, 2, 120, 75))
        else:
            self.widget.setGeometry(QRect(110, 2, 500, 75))
            self.progressBar.setGeometry(QRect(620, 2, 150, 75))

class CommentWidget(QWidget):
    """
    Widget displaying comment author and comment text.
    """
    def __init__(self, author, comment, parent = None):
        """
        Constructor
        """
        QWidget.__init__(self, parent)
        self.textEdit = QTextEdit()
        self.textEdit.setReadOnly(True)
        self.textEdit.viewport().setAutoFillBackground(False)
        self.textEdit.setFrameStyle(QFrame.NoFrame)
        self.textEdit.setStyleSheet("color: rgb(255, 255, 255); font-size: 18px")
        self.document = QTextDocument(unicode(comment, "utf-8"))
        self.textEdit.setDocument(self.document)
        self.textEdit.setFixedHeight(self.document.documentLayout().documentSize().toSize().height())
        self.authorLabel = QLabel(unicode(author, "utf-8"))
        self.authorLabel.setStyleSheet("color: rgb(120, 120, 120) ")
        self.vbox = QVBoxLayout(self)
        self.vbox.addWidget(self.authorLabel)
        self.vbox.addWidget(self.textEdit)
        self.setLayout(self.vbox)
        self.show()

class PlaylistWidget(QWidget):
    def __init__(self, title, parent = None):
        QWidget.__init__(self, parent)
        self.setMininumSize(800, 50)
        self.titleLabel = QLabel(unicode(title, "utf-8"))
        self.titleLabel.setGeometry(QRect(0, 0, 800, 50))
        self.titleLabel.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
        self.show()
